<?php
namespace Magenest\Salesforce\Controller\Adminhtml\Sync;

use Magenest\Salesforce\Model\Sync;
use Magento\Backend\App\Action;
use Magento\Backend\App\Action\Context;
use Magento\Framework\Controller\ResultFactory;

/**
 * Class Account
 * @package Magenest\Salesforce\Controller\Adminhtml\Sync
 */
class Account extends Action
{
    /**
     * @var Sync\Account
     */
    protected $_account;

    /**
     * Customer constructor.
     * @param Context $context
     * @param Sync\Account $account
     */
    public function __construct(
        Context $context,
        Sync\Account $account
    ) {
        $this->_account = $account;
        parent::__construct($context);
    }

    /**
     * @return \Magento\Framework\App\ResponseInterface|\Magento\Framework\Controller\Result\Redirect|\Magento\Framework\Controller\ResultInterface
     */
    public function execute()
    {
        $customerId = $this->getRequest()->getParam('id');
        try {
            if ($customerId) {
                $this->_account->sync($customerId);
                $this->messageManager->addSuccessMessage(
                    __('Account sync process complete, check out Reports for result.')
                );
            } else {
                $this->messageManager->addNoticeMessage(
                    __('No account has been selected')
                );
            }
        } catch (\Throwable $e) {
            $this->messageManager->addErrorMessage(
                __('Something happen during syncing process. Detail: ' . $e->getMessage() . ". Trace: " . $e->getTraceAsString())
            );
        }
        $resultRedirect = $this->resultFactory->create(ResultFactory::TYPE_REDIRECT);
        $resultRedirect->setPath('customer/index/edit', ['id' => $customerId]);
        return $resultRedirect;
    }

    /**
     * @return bool
     */
    protected function _isAllowed()
    {
        return $this->_authorization->isAllowed('Magenest_Salesforce::config_salesforce');
    }
}
